package com.ly.fluttermob;

import com.mob.MobSDK;

import java.util.HashMap;

import cn.sharesdk.framework.Platform;
import cn.sharesdk.framework.PlatformActionListener;
import cn.sharesdk.framework.ShareSDK;
import cn.sharesdk.onekeyshare.OnekeyShare;
import cn.sharesdk.sina.weibo.SinaWeibo;
import cn.sharesdk.tencent.qq.QQ;
import cn.sharesdk.wechat.friends.Wechat;
import cn.sharesdk.wechat.moments.WechatMoments;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

public class FlutterMobPlugin implements MethodCallHandler {

    private Registrar registrar;

    private FlutterMobPlugin(Registrar registrar) {
        this.registrar = registrar;
    }

    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "flutter_mob");
        channel.setMethodCallHandler(new FlutterMobPlugin(registrar));
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        Listener listener = new Listener();
        switch (call.method) {
            case "init":
                String appKey = call.argument("appKey");
                String appSecret = call.argument("appSecret");
                MobSDK.init(registrar.activity(), appKey, appSecret);
                result.success(null);
                break;
            case "config":
                HashMap<String, Object> wechat = call.argument("wechat");
                if (wechat != null) {
                    ShareSDK.setPlatformDevInfo(Wechat.NAME, wechat);
                }
                HashMap<String, Object> wechatMoments = call.argument("wechatMoments");
                if (wechat != null) {
                    ShareSDK.setPlatformDevInfo(WechatMoments.NAME, wechatMoments);
                }
                HashMap<String, Object> qq = call.argument("qq");
                if (wechat != null) {
                    ShareSDK.setPlatformDevInfo(QQ.NAME, qq);
                }
                HashMap<String, Object> sina = call.argument("sina");
                if (wechat != null) {
                    ShareSDK.setPlatformDevInfo(SinaWeibo.NAME, sina);
                }
                result.success(null);
                break;
            case "qqLogin":
                listener.setResult(result);
                Platform qqPlatform = ShareSDK.getPlatform(QQ.NAME);
                qqPlatform.setPlatformActionListener(listener);
                qqPlatform.authorize();
                break;
            case "wechatLogin":
                listener.setResult(result);
                Platform wechatPlatform = ShareSDK.getPlatform(Wechat.NAME);
                wechatPlatform.setPlatformActionListener(listener);
                wechatPlatform.authorize();
                break;
            case "sinaLogin":
                listener.setResult(result);
                Platform sinaPlatform = ShareSDK.getPlatform(SinaWeibo.NAME);
                sinaPlatform.setPlatformActionListener(listener);
                sinaPlatform.authorize();
                break;
            case "share":
                showShare();
                result.success(null);
                break;
        }
    }

    private class Listener implements PlatformActionListener {

        private Result result;

        void setResult(Result result) {
            this.result = result;
        }

        @Override
        public void onComplete(Platform platform, int i, HashMap<String, Object> hashMap) {
            HashMap<String, Object> map = new HashMap<>();
            map.put("status", 0);
            map.put("msg", platform.getDb().exportData());
            result.success(map);
        }

        @Override
        public void onError(Platform platform, int i, Throwable throwable) {
            HashMap<String, Object> map = new HashMap<>();
            map.put("status", 1);
            map.put("msg", throwable.getMessage());
            result.success(map);
        }

        @Override
        public void onCancel(Platform platform, int i) {
            HashMap<String, Object> map = new HashMap<>();
            map.put("status", 2);
            map.put("msg", "cancel");
            result.success(map);
        }
    }

    private void showShare() {
        OnekeyShare oks = new OnekeyShare();
        //关闭sso授权
        oks.disableSSOWhenAuthorize();
        // title标题，微信、QQ和QQ空间等平台使用
        oks.setTitle("1111111");
        // titleUrl QQ和QQ空间跳转链接
        oks.setTitleUrl("http://sharesdk.cn");
        // text是分享文本，所有平台都需要这个字段
        oks.setText("我是分享文本");
        // imagePath是图片的本地路径，Linked-In以外的平台都支持此参数
        // oks.setImagePath("/sdcard/test.jpg");//确保SDcard下面存在此张图片
        // url在微信、微博，Facebook等平台中使用
        oks.setUrl("http://sharesdk.cn");
        // comment是我对这条分享的评论，仅在人人网使用
        oks.setComment("我是测试评论文本");
        // 启动分享GUI
        oks.show(registrar.activity());
    }
}
